@@ -253,7 +253,7 @@ def crelu(input: Tensor, inplace: bool = False) -> Tensor:
     https://arxiv.org/pdf/1705.09792.pdf
     '''
     if input.is_complex():
-        return torch.view_as_complex(torch.stack((F.relu(input.real, inplace=inplace), F.relu(input.imag, inplace=inplace)),dim=-1))
+        return torch.view_as_complex(torch.stack((F.relu(input.real), F.relu(input.imag)),dim=-1))
     else:
         return F.relu(input, inplace=inplace)
 
@@ -287,7 +287,7 @@ def cmodrelu(input: Tensor, threshold: int, inplace: bool = False):
     Source: https://github.com/ivannz/cplxmodule"""
     if input.is_complex():
         modulus = torch.clamp(torch.abs(input), min=1e-5)
-        return input * F.relu(1. - threshold / modulus, inplace=inplace)
+        return input * F.relu(1. - threshold / modulus)
     else:
         return F.relu(input, inplace=inplace)
 
